import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// Colors for the sections in Pie Chart
const sectionColors = [
  		"Maroon",
      "pink",
      "green",
      "cyan",
      "yellow",
      "#014140"
		  ];

// Data set URL
const csvUrl = 'https://gist.githubusercontent.com/Sravan1888/71aeeef7969086aefd9986005ddca265/raw/845547ce1f4ee117733096844973b88d9b571d01/Piechart.csv';

// Function to fetch data from the URI
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

// Select the SVG from the HTML body
const svg = select("svg");
const width = + svg.attr('width');
const height = + svg.attr('height');

// Format axes text
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// Render Pie Chart on the canvas
const render = (data, total) => {
  const pieData = pie().value(d=>d.Percentage)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
  // Object for generating Arcs of the sections
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(200);

  // Segments are the partition in the Pie Chart
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(220,220)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.Percentage));
  
  // Render text on each section
  sections
    .enter()
    .append('text')
    .text(d => xAxisTickFormat((d.data.Percentage))+"%")
    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "middle")
  	.style('fill', 'black')
    .style("font-size", 15);
  
  // Render legend for the data
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // Formats the legend for Deaths
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.Percentage));
  
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.Percentage))+"%");
  
  // Formats the legend for Countries 
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Countries);
  
}

// Main function
const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.Percentage = +d.Percentage;
    total += d.Percentage
  });
	render(data,total);
};
run();